/***************************************************************************
 *
 * $Header: $
 *
 * MODULE DESCRIPTION: 
 * This module implements the "equivalent" call to select() for the
 * RTEMS porting to Microwindows. It relies on the drivers to be
 * non-blocking on reads(), and that events are registered with the
 * drivers.
 * 
 * NOTE: The same thread that opened the Kbd and Mouse drivers, should make
 *       the call to this routine. At this point, this is not a problem
 *       because Microwindows is single threaded. 
 *
 * by: Rosimildo da Silva:
 *     rdasilva@connecttel.com
 *     http://www.connecttel.com
 *
 * MODIFICATION/HISTORY:
 *
 * $Log: $
 ****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/types.h>
#if UNIX
#include <unistd.h>
#include <sys/time.h>
#endif
#include "windows.h"
#include "wintern.h"
#include "device.h"
#include "rtemsinc.h"



/* RTEMS version of select() for MicroWindows */
void GsSelect(void)
{
   rtems_event_set o;
   rtems_status_code rc;
   rtems_interval timeout;
   rtems_option options;

	/* perform pre-select duties, if any*/
	if( scrdev.PreSelect )
   {
		scrdev.PreSelect( &scrdev );
   }

   options = RTEMS_WAIT | RTEMS_EVENT_ANY;
   // Hack: This is a second in ticks. We should get the proper
   // method to make this more generic.
   timeout = 5;

   o = 0;
   rc = rtems_event_receive( RTEMS_KBD_EVENT | RTEMS_MOUSE_EVENT, 
                             options, timeout, &o );
   if( ( rc == RTEMS_TIMEOUT ) || ( rc == RTEMS_UNSATISFIED ) )
   {
      return;
   }

	/* If mouse data present, service it*/
	if( o & RTEMS_MOUSE_EVENT )
   {
     int mouse_had_data;
      do 
      {
         mouse_had_data = GsCheckMouseEvent();
      } while( mouse_had_data );
   }
	/* If keyboard data present, service it*/
	if( o & RTEMS_KBD_EVENT )
   {
      int kbd_had_data;
      do 
      {
         kbd_had_data = GsCheckKeyboardEvent();
      } while( kbd_had_data );
   }
}
